__version__ = "0.0.2"

from telecomlib import shell
from telecomlib import getip
from telecomlib import star

__all__ = [
    "__version__",
    "shell"
]
